@@ -2,8 +2,11 @@ package AnyEvent::Net::Curl::Queued::Easy;
 # ABSTRACT: Net::Curl::Easy wrapped by Any::Moose
 
 
-use common::sense;
 use strict;
+use utf8;
+use warnings qw(all);
+
+use feature qw(switch);
 
 use Carp qw(carp confess);
 use Digest::SHA;
@@ -18,7 +21,7 @@ extends 'Net::Curl::Easy';
 use AnyEvent::Net::Curl::Const;
 use AnyEvent::Net::Curl::Queued::Stats;
 
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 subtype 'AnyEvent::Net::Curl::Queued::Easy::URI'
     => as class_type('URI');
@@ -244,7 +247,7 @@ sub setopt {
 sub getinfo {
     my $self = shift;
 
-    given (ref($_[0])) {
+    for (ref($_[0])) {
         when ('ARRAY') {
             my @val;
             for my $name (@{$_[0]}) {
@@ -300,12 +303,14 @@ AnyEvent::Net::Curl::Queued::Easy - Net::Curl::Easy wrapped by Any::Moose
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
     package MyIEDownloader;
-    use common::sense;
+    use strict;
+    use utf8;
+    use warnings qw(all);
 
     use Any::Moose;
     use Net::Curl::Easy qw(/^CURLOPT_/);
